@@ -20,6 +20,12 @@ class PageBotError(TypeError):
     pass
 
 class PageBotFileFormatError(Exception):
+    """
+
+    >>> e = PageBotFileFormatError('This format is currently not available.')
+    >>> print(e)
+    ! PageBot file format error: This format is currently not available.
+    """
 
     def __init__(self, msg):
         super().__init__()
@@ -27,3 +33,8 @@ class PageBotFileFormatError(Exception):
 
     def __str__(self):
         return '! PageBot file format error: %s' % self.msg
+
+if __name__ == "__main__":
+    import doctest
+    import sys
+    sys.exit(doctest.testmod()[0])
