@@ -39,7 +39,24 @@ def makeStyle(style=None, raiseError=True, **kwargs):
     specific arguments. If style is None, then create a new style dict. In
     that case all the element style values need to be defined by argument. The
     calling element must test if its minimum set (such as self.w and self.h)
-    are properly defined."""
+    are properly defined.
+
+    >>> style = makeStyle()
+    >>> style
+    {}
+    >>> style = makeStyle(style=style)
+    >>> style['fontSize']
+    12pt
+    >>> style = {'bogus': 'bla'}
+    >>> style = makeStyle(style=style, raiseError=False)
+    [makeStyle] Attribute “bogus” not allowed in (root) style!
+    >>> style = {'fontSize': pt(24), 'leading': em(1.2)}
+    >>> style = makeStyle(style=style, raiseError=False)
+    >>> style['fontSize']
+    24pt
+    >>> style['leading']
+    1.2em
+    """
     if style is None:
         new = newStyle(**kwargs)  # Copy arguments in new style.
     else:
@@ -776,7 +793,23 @@ def css(name, e=None, styles=None, default=None):
     """Answers the named style values. Search in optional style dict first,
     otherwise up the parent tree of styles in element e. Both e and style can
     be None. In that case None is answered. Note that this is a generic
-    "Cascading style request", outside the realm of HTML/CSS."""
+    "Cascading style request", outside the realm of HTML/CSS.
+
+    >>> style1 = makeStyle({}, name='style1', fontSize=pt(24))
+    >>> style2 = makeStyle({}, name='style2', fontSize=pt(36))
+    >>> style3 = {'fontSize': pt(48)}
+    >>> styles = [style1, style2]
+    >>> css('fontSize', styles=styles)
+    24pt
+    >>> css('fontSize', styles=style2)
+    36pt
+    >>> from pagebot.elements import newRect
+    >>> e = newRect(style=style3)
+    >>> css('fontSize', e=e)
+    48pt
+    >>> css('fontSize', styles={}, default=pt(12))
+    12pt
+    """
     # Can be single style or stack of styles.
     if styles is not None:
         if not isinstance(styles, (tuple, list)):
